# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: client/admin/v1_7/pps/pps.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from python_pachyderm.proto.admin.v1_7.pfs import pfs_pb2 as client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='client/admin/v1_7/pps/pps.proto',
  package='pps_1_7',
  syntax='proto3',
  serialized_options=b'Z8github.com/pachyderm/pachyderm/src/client/admin/v1_7/pps',
  serialized_pb=b'\n\x1f\x63lient/admin/v1_7/pps/pps.proto\x12\x07pps_1_7\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1f\x63lient/admin/v1_7/pfs/pfs.proto\"H\n\x06Secret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x12\n\nmount_path\x18\x02 \x01(\t\x12\x0f\n\x07\x65nv_var\x18\x03 \x01(\t\"\x98\x02\n\tTransform\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0b\n\x03\x63md\x18\x02 \x03(\t\x12(\n\x03\x65nv\x18\x03 \x03(\x0b\x32\x1b.pps_1_7.Transform.EnvEntry\x12 \n\x07secrets\x18\x04 \x03(\x0b\x32\x0f.pps_1_7.Secret\x12\x1a\n\x12image_pull_secrets\x18\t \x03(\t\x12\r\n\x05stdin\x18\x05 \x03(\t\x12\x1a\n\x12\x61\x63\x63\x65pt_return_code\x18\x06 \x03(\x03\x12\r\n\x05\x64\x65\x62ug\x18\x07 \x01(\x08\x12\x0c\n\x04user\x18\n \x01(\t\x12\x13\n\x0bworking_dir\x18\x0b \x01(\t\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x15\n\x06\x45gress\x12\x0b\n\x03URL\x18\x01 \x01(\t\"\x11\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\"C\n\x07Service\x12\x15\n\rinternal_port\x18\x01 \x01(\x05\x12\x15\n\rexternal_port\x18\x02 \x01(\x05\x12\n\n\x02ip\x18\x03 \x01(\t\"~\n\tAtomInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04repo\x18\x02 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x03 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x04 \x01(\t\x12\x0c\n\x04glob\x18\x05 \x01(\t\x12\x0c\n\x04lazy\x18\x06 \x01(\x08\x12\x13\n\x0b\x65mpty_files\x18\x08 \x01(\x08J\x04\x08\x07\x10\x08\"p\n\tCronInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04repo\x18\x02 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x03 \x01(\t\x12\x0c\n\x04spec\x18\x04 \x01(\t\x12)\n\x05start\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"E\n\x08GitInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x03 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x04 \x01(\t\"\xa9\x01\n\x05Input\x12 \n\x04\x61tom\x18\x01 \x01(\x0b\x32\x12.pps_1_7.AtomInput\x12\x1d\n\x05\x63ross\x18\x02 \x03(\x0b\x32\x0e.pps_1_7.Input\x12\x1d\n\x05union\x18\x03 \x03(\x0b\x32\x0e.pps_1_7.Input\x12 \n\x04\x63ron\x18\x04 \x01(\x0b\x32\x12.pps_1_7.CronInput\x12\x1e\n\x03git\x18\x05 \x01(\x0b\x32\x11.pps_1_7.GitInput\"U\n\x08JobInput\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1f\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0f.pfs_1_7.Commit\x12\x0c\n\x04glob\x18\x02 \x01(\t\x12\x0c\n\x04lazy\x18\x03 \x01(\x08\">\n\x0fParallelismSpec\x12\x10\n\x08\x63onstant\x18\x02 \x01(\x04\x12\x13\n\x0b\x63oefficient\x18\x03 \x01(\x01J\x04\x08\x01\x10\x02\" \n\x0cHashtreeSpec\x12\x10\n\x08\x63onstant\x18\x01 \x01(\x04\"\'\n\tInputFile\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x0c\n\x04hash\x18\x05 \x01(\x0c\".\n\x05\x44\x61tum\x12\n\n\x02id\x18\x01 \x01(\t\x12\x19\n\x03job\x18\x02 \x01(\x0b\x32\x0c.pps_1_7.Job\"\xb7\x01\n\tDatumInfo\x12\x1d\n\x05\x64\x61tum\x18\x01 \x01(\x0b\x32\x0e.pps_1_7.Datum\x12\"\n\x05state\x18\x02 \x01(\x0e\x32\x13.pps_1_7.DatumState\x12$\n\x05stats\x18\x03 \x01(\x0b\x32\x15.pps_1_7.ProcessStats\x12 \n\tpfs_state\x18\x04 \x01(\x0b\x32\r.pfs_1_7.File\x12\x1f\n\x04\x64\x61ta\x18\x05 \x03(\x0b\x32\x11.pfs_1_7.FileInfo\"s\n\tAggregate\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\x0c\n\x04mean\x18\x02 \x01(\x01\x12\x0e\n\x06stddev\x18\x03 \x01(\x01\x12\x18\n\x10\x66ifth_percentile\x18\x04 \x01(\x01\x12\x1f\n\x17ninety_fifth_percentile\x18\x05 \x01(\x01\"\xcf\x01\n\x0cProcessStats\x12\x30\n\rdownload_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0cprocess_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12.\n\x0bupload_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x16\n\x0e\x64ownload_bytes\x18\x04 \x01(\x04\x12\x14\n\x0cupload_bytes\x18\x05 \x01(\x04\"\xeb\x01\n\x15\x41ggregateProcessStats\x12)\n\rdownload_time\x18\x01 \x01(\x0b\x32\x12.pps_1_7.Aggregate\x12(\n\x0cprocess_time\x18\x02 \x01(\x0b\x32\x12.pps_1_7.Aggregate\x12\'\n\x0bupload_time\x18\x03 \x01(\x0b\x32\x12.pps_1_7.Aggregate\x12*\n\x0e\x64ownload_bytes\x18\x04 \x01(\x0b\x32\x12.pps_1_7.Aggregate\x12(\n\x0cupload_bytes\x18\x05 \x01(\x0b\x32\x12.pps_1_7.Aggregate\"\xba\x01\n\x0cWorkerStatus\x12\x11\n\tworker_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12 \n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x12.pps_1_7.InputFile\x12+\n\x07started\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x05stats\x18\x05 \x01(\x0b\x32\x15.pps_1_7.ProcessStats\x12\x12\n\nqueue_size\x18\x06 \x01(\x03\"F\n\x0cResourceSpec\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x02\x12\x0e\n\x06memory\x18\x02 \x01(\t\x12\x0b\n\x03gpu\x18\x03 \x01(\x03\x12\x0c\n\x04\x64isk\x18\x04 \x01(\t\"\xb7\x03\n\x0b\x45tcdJobInfo\x12\x19\n\x03job\x18\x01 \x01(\x0b\x32\x0c.pps_1_7.Job\x12#\n\x08pipeline\x18\x02 \x01(\x0b\x32\x11.pps_1_7.Pipeline\x12&\n\routput_commit\x18\x03 \x01(\x0b\x32\x0f.pfs_1_7.Commit\x12\x0f\n\x07restart\x18\x04 \x01(\x04\x12\x16\n\x0e\x64\x61ta_processed\x18\x05 \x01(\x03\x12\x14\n\x0c\x64\x61ta_skipped\x18\x06 \x01(\x03\x12\x12\n\ndata_total\x18\x07 \x01(\x03\x12\x13\n\x0b\x64\x61ta_failed\x18\x08 \x01(\x03\x12$\n\x05stats\x18\t \x01(\x0b\x32\x15.pps_1_7.ProcessStats\x12%\n\x0cstats_commit\x18\n \x01(\x0b\x32\x0f.pfs_1_7.Commit\x12 \n\x05state\x18\x0b \x01(\x0e\x32\x11.pps_1_7.JobState\x12\x0e\n\x06reason\x18\x0c \x01(\t\x12+\n\x07started\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x66inished\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xd8\t\n\x07JobInfo\x12\x19\n\x03job\x18\x01 \x01(\x0b\x32\x0c.pps_1_7.Job\x12%\n\ttransform\x18\x02 \x01(\x0b\x32\x12.pps_1_7.Transform\x12#\n\x08pipeline\x18\x03 \x01(\x0b\x32\x11.pps_1_7.Pipeline\x12\x18\n\x10pipeline_version\x18\r \x01(\x04\x12\x32\n\x10parallelism_spec\x18\x0c \x01(\x0b\x32\x18.pps_1_7.ParallelismSpec\x12\x1f\n\x06\x65gress\x18\x0f \x01(\x0b\x32\x0f.pps_1_7.Egress\x12 \n\nparent_job\x18\x06 \x01(\x0b\x32\x0c.pps_1_7.Job\x12+\n\x07started\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x66inished\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\routput_commit\x18\t \x01(\x0b\x32\x0f.pfs_1_7.Commit\x12 \n\x05state\x18\n \x01(\x0e\x32\x11.pps_1_7.JobState\x12\x0e\n\x06reason\x18# \x01(\t\x12!\n\x07service\x18\x0e \x01(\x0b\x32\x10.pps_1_7.Service\x12\"\n\x0boutput_repo\x18\x12 \x01(\x0b\x32\r.pfs_1_7.Repo\x12\x15\n\routput_branch\x18\x11 \x01(\t\x12\x0f\n\x07restart\x18\x14 \x01(\x04\x12\x16\n\x0e\x64\x61ta_processed\x18\x16 \x01(\x03\x12\x14\n\x0c\x64\x61ta_skipped\x18\x1e \x01(\x03\x12\x13\n\x0b\x64\x61ta_failed\x18( \x01(\x03\x12\x12\n\ndata_total\x18\x17 \x01(\x03\x12$\n\x05stats\x18\x1f \x01(\x0b\x32\x15.pps_1_7.ProcessStats\x12,\n\rworker_status\x18\x18 \x03(\x0b\x32\x15.pps_1_7.WorkerStatus\x12\x30\n\x11resource_requests\x18\x19 \x01(\x0b\x32\x15.pps_1_7.ResourceSpec\x12.\n\x0fresource_limits\x18$ \x01(\x0b\x32\x15.pps_1_7.ResourceSpec\x12\x1d\n\x05input\x18\x1a \x01(\x0b\x32\x0e.pps_1_7.Input\x12\'\n\nnew_branch\x18\x1b \x01(\x0b\x32\x13.pfs_1_7.BranchInfo\x12\x13\n\x0bincremental\x18\x1c \x01(\x08\x12%\n\x0cstats_commit\x18\x1d \x01(\x0b\x32\x0f.pfs_1_7.Commit\x12\x14\n\x0c\x65nable_stats\x18  \x01(\x08\x12\x0c\n\x04salt\x18! \x01(\t\x12\r\n\x05\x62\x61tch\x18\" \x01(\x08\x12&\n\nchunk_spec\x18% \x01(\x0b\x32\x12.pps_1_7.ChunkSpec\x12\x30\n\rdatum_timeout\x18& \x01(\x0b\x32\x19.google.protobuf.Duration\x12.\n\x0bjob_timeout\x18\' \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x13\n\x0b\x64\x61tum_tries\x18) \x01(\x03\x12\x30\n\x0fscheduling_spec\x18* \x01(\x0b\x32\x17.pps_1_7.SchedulingSpec\x12\x10\n\x08pod_spec\x18+ \x01(\tJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\";\n\x06Worker\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x05state\x18\x02 \x01(\x0e\x32\x14.pps_1_7.WorkerState\".\n\x08JobInfos\x12\"\n\x08job_info\x18\x01 \x03(\x0b\x32\x10.pps_1_7.JobInfo\"\x18\n\x08Pipeline\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x85\x01\n\rPipelineInput\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x1b\n\x04repo\x18\x01 \x01(\x0b\x32\r.pfs_1_7.Repo\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\x12\x0c\n\x04glob\x18\x03 \x01(\t\x12\x0c\n\x04lazy\x18\x04 \x01(\x08\x12\x1d\n\x04\x66rom\x18\x06 \x01(\x0b\x32\x0f.pfs_1_7.Commit\"\xf3\x01\n\x10\x45tcdPipelineInfo\x12%\n\x05state\x18\x01 \x01(\x0e\x32\x16.pps_1_7.PipelineState\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12$\n\x0bspec_commit\x18\x02 \x01(\x0b\x32\x0f.pfs_1_7.Commit\x12<\n\njob_counts\x18\x03 \x03(\x0b\x32(.pps_1_7.EtcdPipelineInfo.JobCountsEntry\x12\x12\n\nauth_token\x18\x05 \x01(\t\x1a\x30\n\x0eJobCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\xb2\t\n\x0cPipelineInfo\x12\n\n\x02id\x18\x11 \x01(\t\x12#\n\x08pipeline\x18\x01 \x01(\x0b\x32\x11.pps_1_7.Pipeline\x12\x0f\n\x07version\x18\x0b \x01(\x04\x12%\n\ttransform\x18\x02 \x01(\x0b\x32\x12.pps_1_7.Transform\x12\x32\n\x10parallelism_spec\x18\n \x01(\x0b\x32\x18.pps_1_7.ParallelismSpec\x12,\n\rhashtree_spec\x18* \x01(\x0b\x32\x15.pps_1_7.HashtreeSpec\x12\x1f\n\x06\x65gress\x18\x0f \x01(\x0b\x32\x0f.pps_1_7.Egress\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12%\n\x05state\x18\x07 \x01(\x0e\x32\x16.pps_1_7.PipelineState\x12\x0f\n\x07stopped\x18& \x01(\x08\x12\x14\n\x0crecent_error\x18\x08 \x01(\t\x12\x38\n\njob_counts\x18\t \x03(\x0b\x32$.pps_1_7.PipelineInfo.JobCountsEntry\x12\x15\n\routput_branch\x18\x10 \x01(\t\x12\x37\n\x14scale_down_threshold\x18\x12 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x30\n\x11resource_requests\x18\x13 \x01(\x0b\x32\x15.pps_1_7.ResourceSpec\x12.\n\x0fresource_limits\x18\x1f \x01(\x0b\x32\x15.pps_1_7.ResourceSpec\x12\x1d\n\x05input\x18\x14 \x01(\x0b\x32\x0e.pps_1_7.Input\x12\x13\n\x0b\x64\x65scription\x18\x15 \x01(\t\x12\x13\n\x0bincremental\x18\x16 \x01(\x08\x12\x12\n\ncache_size\x18\x17 \x01(\t\x12\x14\n\x0c\x65nable_stats\x18\x18 \x01(\x08\x12\x0c\n\x04salt\x18\x19 \x01(\t\x12\r\n\x05\x62\x61tch\x18\x1b \x01(\x08\x12\x0e\n\x06reason\x18\x1c \x01(\t\x12\x16\n\x0emax_queue_size\x18\x1d \x01(\x03\x12!\n\x07service\x18\x1e \x01(\x0b\x32\x10.pps_1_7.Service\x12&\n\nchunk_spec\x18  \x01(\x0b\x32\x12.pps_1_7.ChunkSpec\x12\x30\n\rdatum_timeout\x18! \x01(\x0b\x32\x19.google.protobuf.Duration\x12.\n\x0bjob_timeout\x18\" \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x13\n\x0bgithook_url\x18# \x01(\t\x12$\n\x0bspec_commit\x18$ \x01(\x0b\x32\x0f.pfs_1_7.Commit\x12\x0f\n\x07standby\x18% \x01(\x08\x12\x13\n\x0b\x64\x61tum_tries\x18\' \x01(\x03\x12\x30\n\x0fscheduling_spec\x18( \x01(\x0b\x32\x17.pps_1_7.SchedulingSpec\x12\x10\n\x08pod_spec\x18) \x01(\t\x1a\x30\n\x0eJobCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x1a\x10\x1b\"=\n\rPipelineInfos\x12,\n\rpipeline_info\x18\x01 \x03(\x0b\x32\x15.pps_1_7.PipelineInfo\"\xdd\x01\n\x10\x43reateJobRequest\x12#\n\x08pipeline\x18\x02 \x01(\x0b\x32\x11.pps_1_7.Pipeline\x12&\n\routput_commit\x18\x19 \x01(\x0b\x32\x0f.pfs_1_7.CommitJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x01\x10\x02J\x04\x08\n\x10\x0bJ\x04\x08\x07\x10\x08J\x04\x08\t\x10\nJ\x04\x08\x08\x10\tJ\x04\x08\x0c\x10\rJ\x04\x08\x0b\x10\x0cJ\x04\x08\r\x10\x0eJ\x04\x08\x0e\x10\x0fJ\x04\x08\x15\x10\x16J\x04\x08\x0f\x10\x10J\x04\x08\x10\x10\x11J\x04\x08\x11\x10\x12J\x04\x08\x12\x10\x13J\x04\x08\x13\x10\x14J\x04\x08\x14\x10\x15J\x04\x08\x16\x10\x17J\x04\x08\x17\x10\x18J\x04\x08\x18\x10\x19\"k\n\x11InspectJobRequest\x12\x19\n\x03job\x18\x01 \x01(\x0b\x32\x0c.pps_1_7.Job\x12&\n\routput_commit\x18\x03 \x01(\x0b\x32\x0f.pfs_1_7.Commit\x12\x13\n\x0b\x62lock_state\x18\x02 \x01(\x08\"\x84\x01\n\x0eListJobRequest\x12#\n\x08pipeline\x18\x01 \x01(\x0b\x32\x11.pps_1_7.Pipeline\x12%\n\x0cinput_commit\x18\x02 \x03(\x0b\x32\x0f.pfs_1_7.Commit\x12&\n\routput_commit\x18\x03 \x01(\x0b\x32\x0f.pfs_1_7.Commit\"\\\n\x0f\x46lushJobRequest\x12 \n\x07\x63ommits\x18\x01 \x03(\x0b\x32\x0f.pfs_1_7.Commit\x12\'\n\x0cto_pipelines\x18\x02 \x03(\x0b\x32\x11.pps_1_7.Pipeline\"-\n\x10\x44\x65leteJobRequest\x12\x19\n\x03job\x18\x01 \x01(\x0b\x32\x0c.pps_1_7.Job\"+\n\x0eStopJobRequest\x12\x19\n\x03job\x18\x01 \x01(\x0b\x32\x0c.pps_1_7.Job\"\xb9\x01\n\x0eGetLogsRequest\x12#\n\x08pipeline\x18\x02 \x01(\x0b\x32\x11.pps_1_7.Pipeline\x12\x19\n\x03job\x18\x01 \x01(\x0b\x32\x0c.pps_1_7.Job\x12\x14\n\x0c\x64\x61ta_filters\x18\x03 \x03(\t\x12\x1d\n\x05\x64\x61tum\x18\x06 \x01(\x0b\x32\x0e.pps_1_7.Datum\x12\x0e\n\x06master\x18\x05 \x01(\x08\x12\x0e\n\x06\x66ollow\x18\x07 \x01(\x08\x12\x0c\n\x04tail\x18\x08 \x01(\x03J\x04\x08\x04\x10\x05\"\xd1\x01\n\nLogMessage\x12\x15\n\rpipeline_name\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x03 \x01(\t\x12\x11\n\tworker_id\x18\x07 \x01(\t\x12\x10\n\x08\x64\x61tum_id\x18\t \x01(\t\x12\x0e\n\x06master\x18\n \x01(\x08\x12 \n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x12.pps_1_7.InputFile\x12\x0c\n\x04user\x18\x08 \x01(\x08\x12&\n\x02ts\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x06 \x01(\t\"F\n\x13RestartDatumRequest\x12\x19\n\x03job\x18\x01 \x01(\x0b\x32\x0c.pps_1_7.Job\x12\x14\n\x0c\x64\x61ta_filters\x18\x02 \x03(\t\"4\n\x13InspectDatumRequest\x12\x1d\n\x05\x64\x61tum\x18\x01 \x01(\x0b\x32\x0e.pps_1_7.Datum\"N\n\x10ListDatumRequest\x12\x19\n\x03job\x18\x01 \x01(\x0b\x32\x0c.pps_1_7.Job\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x0c\n\x04page\x18\x03 \x01(\x03\"_\n\x11ListDatumResponse\x12\'\n\x0b\x64\x61tum_infos\x18\x01 \x03(\x0b\x32\x12.pps_1_7.DatumInfo\x12\x13\n\x0btotal_pages\x18\x02 \x01(\x03\x12\x0c\n\x04page\x18\x03 \x01(\x03\"d\n\x17ListDatumStreamResponse\x12&\n\ndatum_info\x18\x01 \x01(\x0b\x32\x12.pps_1_7.DatumInfo\x12\x13\n\x0btotal_pages\x18\x02 \x01(\x03\x12\x0c\n\x04page\x18\x03 \x01(\x03\"/\n\tChunkSpec\x12\x0e\n\x06number\x18\x01 \x01(\x03\x12\x12\n\nsize_bytes\x18\x02 \x01(\x03\"\xa4\x01\n\x0eSchedulingSpec\x12@\n\rnode_selector\x18\x01 \x03(\x0b\x32).pps_1_7.SchedulingSpec.NodeSelectorEntry\x12\x1b\n\x13priority_class_name\x18\x02 \x01(\t\x1a\x33\n\x11NodeSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x07\n\x15\x43reatePipelineRequest\x12#\n\x08pipeline\x18\x01 \x01(\x0b\x32\x11.pps_1_7.Pipeline\x12%\n\ttransform\x18\x02 \x01(\x0b\x32\x12.pps_1_7.Transform\x12\x32\n\x10parallelism_spec\x18\x07 \x01(\x0b\x32\x18.pps_1_7.ParallelismSpec\x12,\n\rhashtree_spec\x18\x1f \x01(\x0b\x32\x15.pps_1_7.HashtreeSpec\x12\x1f\n\x06\x65gress\x18\t \x01(\x0b\x32\x0f.pps_1_7.Egress\x12\x0e\n\x06update\x18\x05 \x01(\x08\x12\x15\n\routput_branch\x18\n \x01(\t\x12\x37\n\x14scale_down_threshold\x18\x0b \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x30\n\x11resource_requests\x18\x0c \x01(\x0b\x32\x15.pps_1_7.ResourceSpec\x12.\n\x0fresource_limits\x18\x16 \x01(\x0b\x32\x15.pps_1_7.ResourceSpec\x12\x1d\n\x05input\x18\r \x01(\x0b\x32\x0e.pps_1_7.Input\x12\x13\n\x0b\x64\x65scription\x18\x0e \x01(\t\x12\x13\n\x0bincremental\x18\x0f \x01(\x08\x12\x12\n\ncache_size\x18\x10 \x01(\t\x12\x14\n\x0c\x65nable_stats\x18\x11 \x01(\x08\x12\x11\n\treprocess\x18\x12 \x01(\x08\x12\r\n\x05\x62\x61tch\x18\x13 \x01(\x08\x12\x16\n\x0emax_queue_size\x18\x14 \x01(\x03\x12!\n\x07service\x18\x15 \x01(\x0b\x32\x10.pps_1_7.Service\x12&\n\nchunk_spec\x18\x17 \x01(\x0b\x32\x12.pps_1_7.ChunkSpec\x12\x30\n\rdatum_timeout\x18\x18 \x01(\x0b\x32\x19.google.protobuf.Duration\x12.\n\x0bjob_timeout\x18\x19 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0c\n\x04salt\x18\x1a \x01(\t\x12\x0f\n\x07standby\x18\x1b \x01(\x08\x12\x13\n\x0b\x64\x61tum_tries\x18\x1c \x01(\x03\x12\x30\n\x0fscheduling_spec\x18\x1d \x01(\x0b\x32\x17.pps_1_7.SchedulingSpec\x12\x10\n\x08pod_spec\x18\x1e \x01(\tJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"=\n\x16InspectPipelineRequest\x12#\n\x08pipeline\x18\x01 \x01(\x0b\x32\x11.pps_1_7.Pipeline\"\x15\n\x13ListPipelineRequest\"d\n\x15\x44\x65letePipelineRequest\x12#\n\x08pipeline\x18\x01 \x01(\x0b\x32\x11.pps_1_7.Pipeline\x12\x0b\n\x03\x61ll\x18\x04 \x01(\x08\x12\r\n\x05\x66orce\x18\x05 \x01(\x08J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\";\n\x14StartPipelineRequest\x12#\n\x08pipeline\x18\x01 \x01(\x0b\x32\x11.pps_1_7.Pipeline\":\n\x13StopPipelineRequest\x12#\n\x08pipeline\x18\x01 \x01(\x0b\x32\x11.pps_1_7.Pipeline\"\x7f\n\x14RerunPipelineRequest\x12#\n\x08pipeline\x18\x01 \x01(\x0b\x32\x11.pps_1_7.Pipeline\x12 \n\x07\x65xclude\x18\x02 \x03(\x0b\x32\x0f.pfs_1_7.Commit\x12 \n\x07include\x18\x03 \x03(\x0b\x32\x0f.pfs_1_7.Commit\"-\n\x15GarbageCollectRequest\x12\x14\n\x0cmemory_bytes\x18\x01 \x01(\x03\"\x18\n\x16GarbageCollectResponse\"\x15\n\x13\x41\x63tivateAuthRequest\"\x16\n\x14\x41\x63tivateAuthResponse*_\n\x08JobState\x12\x10\n\x0cJOB_STARTING\x10\x00\x12\x0f\n\x0bJOB_RUNNING\x10\x01\x12\x0f\n\x0bJOB_FAILURE\x10\x02\x12\x0f\n\x0bJOB_SUCCESS\x10\x03\x12\x0e\n\nJOB_KILLED\x10\x04*@\n\nDatumState\x12\n\n\x06\x46\x41ILED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x0b\n\x07SKIPPED\x10\x02\x12\x0c\n\x08STARTING\x10\x03*?\n\x0bWorkerState\x12\x0f\n\x0bPOD_RUNNING\x10\x00\x12\x0f\n\x0bPOD_SUCCESS\x10\x01\x12\x0e\n\nPOD_FAILED\x10\x02*\x96\x01\n\rPipelineState\x12\x15\n\x11PIPELINE_STARTING\x10\x00\x12\x14\n\x10PIPELINE_RUNNING\x10\x01\x12\x17\n\x13PIPELINE_RESTARTING\x10\x02\x12\x14\n\x10PIPELINE_FAILURE\x10\x03\x12\x13\n\x0fPIPELINE_PAUSED\x10\x04\x12\x14\n\x10PIPELINE_STANDBY\x10\x05\x32\xff\x0b\n\x03\x41PI\x12\x36\n\tCreateJob\x12\x19.pps_1_7.CreateJobRequest\x1a\x0c.pps_1_7.Job\"\x00\x12<\n\nInspectJob\x12\x1a.pps_1_7.InspectJobRequest\x1a\x10.pps_1_7.JobInfo\"\x00\x12\x37\n\x07ListJob\x12\x17.pps_1_7.ListJobRequest\x1a\x11.pps_1_7.JobInfos\"\x00\x12>\n\rListJobStream\x12\x17.pps_1_7.ListJobRequest\x1a\x10.pps_1_7.JobInfo\"\x00\x30\x01\x12:\n\x08\x46lushJob\x12\x18.pps_1_7.FlushJobRequest\x1a\x10.pps_1_7.JobInfo\"\x00\x30\x01\x12@\n\tDeleteJob\x12\x19.pps_1_7.DeleteJobRequest\x1a\x16.google.protobuf.Empty\"\x00\x12<\n\x07StopJob\x12\x17.pps_1_7.StopJobRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x42\n\x0cInspectDatum\x12\x1c.pps_1_7.InspectDatumRequest\x1a\x12.pps_1_7.DatumInfo\"\x00\x12\x44\n\tListDatum\x12\x19.pps_1_7.ListDatumRequest\x1a\x1a.pps_1_7.ListDatumResponse\"\x00\x12R\n\x0fListDatumStream\x12\x19.pps_1_7.ListDatumRequest\x1a .pps_1_7.ListDatumStreamResponse\"\x00\x30\x01\x12\x46\n\x0cRestartDatum\x12\x1c.pps_1_7.RestartDatumRequest\x1a\x16.google.protobuf.Empty\"\x00\x12J\n\x0e\x43reatePipeline\x12\x1e.pps_1_7.CreatePipelineRequest\x1a\x16.google.protobuf.Empty\"\x00\x12K\n\x0fInspectPipeline\x12\x1f.pps_1_7.InspectPipelineRequest\x1a\x15.pps_1_7.PipelineInfo\"\x00\x12\x46\n\x0cListPipeline\x12\x1c.pps_1_7.ListPipelineRequest\x1a\x16.pps_1_7.PipelineInfos\"\x00\x12J\n\x0e\x44\x65letePipeline\x12\x1e.pps_1_7.DeletePipelineRequest\x1a\x16.google.protobuf.Empty\"\x00\x12H\n\rStartPipeline\x12\x1d.pps_1_7.StartPipelineRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x46\n\x0cStopPipeline\x12\x1c.pps_1_7.StopPipelineRequest\x1a\x16.google.protobuf.Empty\"\x00\x12H\n\rRerunPipeline\x12\x1d.pps_1_7.RerunPipelineRequest\x1a\x16.google.protobuf.Empty\"\x00\x12=\n\tDeleteAll\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12;\n\x07GetLogs\x12\x17.pps_1_7.GetLogsRequest\x1a\x13.pps_1_7.LogMessage\"\x00\x30\x01\x12S\n\x0eGarbageCollect\x12\x1e.pps_1_7.GarbageCollectRequest\x1a\x1f.pps_1_7.GarbageCollectResponse\"\x00\x12M\n\x0c\x41\x63tivateAuth\x12\x1c.pps_1_7.ActivateAuthRequest\x1a\x1d.pps_1_7.ActivateAuthResponse\"\x00\x42:Z8github.com/pachyderm/pachyderm/src/client/admin/v1_7/ppsb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2.DESCRIPTOR,])

_JOBSTATE = _descriptor.EnumDescriptor(
  name='JobState',
  full_name='pps_1_7.JobState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='JOB_STARTING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JOB_RUNNING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JOB_FAILURE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JOB_SUCCESS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JOB_KILLED', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9018,
  serialized_end=9113,
)
_sym_db.RegisterEnumDescriptor(_JOBSTATE)

JobState = enum_type_wrapper.EnumTypeWrapper(_JOBSTATE)
_DATUMSTATE = _descriptor.EnumDescriptor(
  name='DatumState',
  full_name='pps_1_7.DatumState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SKIPPED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9115,
  serialized_end=9179,
)
_sym_db.RegisterEnumDescriptor(_DATUMSTATE)

DatumState = enum_type_wrapper.EnumTypeWrapper(_DATUMSTATE)
_WORKERSTATE = _descriptor.EnumDescriptor(
  name='WorkerState',
  full_name='pps_1_7.WorkerState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='POD_RUNNING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POD_SUCCESS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POD_FAILED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9181,
  serialized_end=9244,
)
_sym_db.RegisterEnumDescriptor(_WORKERSTATE)

WorkerState = enum_type_wrapper.EnumTypeWrapper(_WORKERSTATE)
_PIPELINESTATE = _descriptor.EnumDescriptor(
  name='PipelineState',
  full_name='pps_1_7.PipelineState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_STARTING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_RUNNING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_RESTARTING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_FAILURE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_PAUSED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_STANDBY', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9247,
  serialized_end=9397,
)
_sym_db.RegisterEnumDescriptor(_PIPELINESTATE)

PipelineState = enum_type_wrapper.EnumTypeWrapper(_PIPELINESTATE)
JOB_STARTING = 0
JOB_RUNNING = 1
JOB_FAILURE = 2
JOB_SUCCESS = 3
JOB_KILLED = 4
FAILED = 0
SUCCESS = 1
SKIPPED = 2
STARTING = 3
POD_RUNNING = 0
POD_SUCCESS = 1
POD_FAILED = 2
PIPELINE_STARTING = 0
PIPELINE_RUNNING = 1
PIPELINE_RESTARTING = 2
PIPELINE_FAILURE = 3
PIPELINE_PAUSED = 4
PIPELINE_STANDBY = 5



_SECRET = _descriptor.Descriptor(
  name='Secret',
  full_name='pps_1_7.Secret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='pps_1_7.Secret.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='pps_1_7.Secret.key', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mount_path', full_name='pps_1_7.Secret.mount_path', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='env_var', full_name='pps_1_7.Secret.env_var', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=243,
)


_TRANSFORM_ENVENTRY = _descriptor.Descriptor(
  name='EnvEntry',
  full_name='pps_1_7.Transform.EnvEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='pps_1_7.Transform.EnvEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='pps_1_7.Transform.EnvEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=484,
  serialized_end=526,
)

_TRANSFORM = _descriptor.Descriptor(
  name='Transform',
  full_name='pps_1_7.Transform',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='pps_1_7.Transform.image', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cmd', full_name='pps_1_7.Transform.cmd', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='env', full_name='pps_1_7.Transform.env', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secrets', full_name='pps_1_7.Transform.secrets', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_pull_secrets', full_name='pps_1_7.Transform.image_pull_secrets', index=4,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stdin', full_name='pps_1_7.Transform.stdin', index=5,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accept_return_code', full_name='pps_1_7.Transform.accept_return_code', index=6,
      number=6, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debug', full_name='pps_1_7.Transform.debug', index=7,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='pps_1_7.Transform.user', index=8,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='working_dir', full_name='pps_1_7.Transform.working_dir', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TRANSFORM_ENVENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=246,
  serialized_end=526,
)


_EGRESS = _descriptor.Descriptor(
  name='Egress',
  full_name='pps_1_7.Egress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='URL', full_name='pps_1_7.Egress.URL', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=528,
  serialized_end=549,
)


_JOB = _descriptor.Descriptor(
  name='Job',
  full_name='pps_1_7.Job',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='pps_1_7.Job.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=551,
  serialized_end=568,
)


_SERVICE = _descriptor.Descriptor(
  name='Service',
  full_name='pps_1_7.Service',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='internal_port', full_name='pps_1_7.Service.internal_port', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='external_port', full_name='pps_1_7.Service.external_port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip', full_name='pps_1_7.Service.ip', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=637,
)


_ATOMINPUT = _descriptor.Descriptor(
  name='AtomInput',
  full_name='pps_1_7.AtomInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='pps_1_7.AtomInput.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repo', full_name='pps_1_7.AtomInput.repo', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='pps_1_7.AtomInput.branch', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit', full_name='pps_1_7.AtomInput.commit', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='glob', full_name='pps_1_7.AtomInput.glob', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lazy', full_name='pps_1_7.AtomInput.lazy', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='empty_files', full_name='pps_1_7.AtomInput.empty_files', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=639,
  serialized_end=765,
)


_CRONINPUT = _descriptor.Descriptor(
  name='CronInput',
  full_name='pps_1_7.CronInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='pps_1_7.CronInput.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repo', full_name='pps_1_7.CronInput.repo', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit', full_name='pps_1_7.CronInput.commit', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='pps_1_7.CronInput.spec', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='pps_1_7.CronInput.start', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=767,
  serialized_end=879,
)


_GITINPUT = _descriptor.Descriptor(
  name='GitInput',
  full_name='pps_1_7.GitInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='pps_1_7.GitInput.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='pps_1_7.GitInput.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='pps_1_7.GitInput.branch', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit', full_name='pps_1_7.GitInput.commit', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=881,
  serialized_end=950,
)


_INPUT = _descriptor.Descriptor(
  name='Input',
  full_name='pps_1_7.Input',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='atom', full_name='pps_1_7.Input.atom', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cross', full_name='pps_1_7.Input.cross', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='union', full_name='pps_1_7.Input.union', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cron', full_name='pps_1_7.Input.cron', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='git', full_name='pps_1_7.Input.git', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=953,
  serialized_end=1122,
)


_JOBINPUT = _descriptor.Descriptor(
  name='JobInput',
  full_name='pps_1_7.JobInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='pps_1_7.JobInput.name', index=0,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit', full_name='pps_1_7.JobInput.commit', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='glob', full_name='pps_1_7.JobInput.glob', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lazy', full_name='pps_1_7.JobInput.lazy', index=3,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1124,
  serialized_end=1209,
)


_PARALLELISMSPEC = _descriptor.Descriptor(
  name='ParallelismSpec',
  full_name='pps_1_7.ParallelismSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='constant', full_name='pps_1_7.ParallelismSpec.constant', index=0,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coefficient', full_name='pps_1_7.ParallelismSpec.coefficient', index=1,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1211,
  serialized_end=1273,
)


_HASHTREESPEC = _descriptor.Descriptor(
  name='HashtreeSpec',
  full_name='pps_1_7.HashtreeSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='constant', full_name='pps_1_7.HashtreeSpec.constant', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1275,
  serialized_end=1307,
)


_INPUTFILE = _descriptor.Descriptor(
  name='InputFile',
  full_name='pps_1_7.InputFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='pps_1_7.InputFile.path', index=0,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='pps_1_7.InputFile.hash', index=1,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1309,
  serialized_end=1348,
)


_DATUM = _descriptor.Descriptor(
  name='Datum',
  full_name='pps_1_7.Datum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='pps_1_7.Datum.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job', full_name='pps_1_7.Datum.job', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1350,
  serialized_end=1396,
)


_DATUMINFO = _descriptor.Descriptor(
  name='DatumInfo',
  full_name='pps_1_7.DatumInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='datum', full_name='pps_1_7.DatumInfo.datum', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='pps_1_7.DatumInfo.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='pps_1_7.DatumInfo.stats', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pfs_state', full_name='pps_1_7.DatumInfo.pfs_state', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='pps_1_7.DatumInfo.data', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1399,
  serialized_end=1582,
)


_AGGREGATE = _descriptor.Descriptor(
  name='Aggregate',
  full_name='pps_1_7.Aggregate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='pps_1_7.Aggregate.count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mean', full_name='pps_1_7.Aggregate.mean', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stddev', full_name='pps_1_7.Aggregate.stddev', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fifth_percentile', full_name='pps_1_7.Aggregate.fifth_percentile', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ninety_fifth_percentile', full_name='pps_1_7.Aggregate.ninety_fifth_percentile', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1584,
  serialized_end=1699,
)


_PROCESSSTATS = _descriptor.Descriptor(
  name='ProcessStats',
  full_name='pps_1_7.ProcessStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='download_time', full_name='pps_1_7.ProcessStats.download_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_time', full_name='pps_1_7.ProcessStats.process_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upload_time', full_name='pps_1_7.ProcessStats.upload_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='download_bytes', full_name='pps_1_7.ProcessStats.download_bytes', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upload_bytes', full_name='pps_1_7.ProcessStats.upload_bytes', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1702,
  serialized_end=1909,
)


_AGGREGATEPROCESSSTATS = _descriptor.Descriptor(
  name='AggregateProcessStats',
  full_name='pps_1_7.AggregateProcessStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='download_time', full_name='pps_1_7.AggregateProcessStats.download_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_time', full_name='pps_1_7.AggregateProcessStats.process_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upload_time', full_name='pps_1_7.AggregateProcessStats.upload_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='download_bytes', full_name='pps_1_7.AggregateProcessStats.download_bytes', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upload_bytes', full_name='pps_1_7.AggregateProcessStats.upload_bytes', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1912,
  serialized_end=2147,
)


_WORKERSTATUS = _descriptor.Descriptor(
  name='WorkerStatus',
  full_name='pps_1_7.WorkerStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_id', full_name='pps_1_7.WorkerStatus.worker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='pps_1_7.WorkerStatus.job_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='pps_1_7.WorkerStatus.data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='started', full_name='pps_1_7.WorkerStatus.started', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='pps_1_7.WorkerStatus.stats', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue_size', full_name='pps_1_7.WorkerStatus.queue_size', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2150,
  serialized_end=2336,
)


_RESOURCESPEC = _descriptor.Descriptor(
  name='ResourceSpec',
  full_name='pps_1_7.ResourceSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpu', full_name='pps_1_7.ResourceSpec.cpu', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memory', full_name='pps_1_7.ResourceSpec.memory', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gpu', full_name='pps_1_7.ResourceSpec.gpu', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disk', full_name='pps_1_7.ResourceSpec.disk', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2338,
  serialized_end=2408,
)


_ETCDJOBINFO = _descriptor.Descriptor(
  name='EtcdJobInfo',
  full_name='pps_1_7.EtcdJobInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='pps_1_7.EtcdJobInfo.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='pps_1_7.EtcdJobInfo.pipeline', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_commit', full_name='pps_1_7.EtcdJobInfo.output_commit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restart', full_name='pps_1_7.EtcdJobInfo.restart', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_processed', full_name='pps_1_7.EtcdJobInfo.data_processed', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_skipped', full_name='pps_1_7.EtcdJobInfo.data_skipped', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_total', full_name='pps_1_7.EtcdJobInfo.data_total', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_failed', full_name='pps_1_7.EtcdJobInfo.data_failed', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='pps_1_7.EtcdJobInfo.stats', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats_commit', full_name='pps_1_7.EtcdJobInfo.stats_commit', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='pps_1_7.EtcdJobInfo.state', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reason', full_name='pps_1_7.EtcdJobInfo.reason', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='started', full_name='pps_1_7.EtcdJobInfo.started', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='finished', full_name='pps_1_7.EtcdJobInfo.finished', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2411,
  serialized_end=2850,
)


_JOBINFO = _descriptor.Descriptor(
  name='JobInfo',
  full_name='pps_1_7.JobInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='pps_1_7.JobInfo.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transform', full_name='pps_1_7.JobInfo.transform', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='pps_1_7.JobInfo.pipeline', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pipeline_version', full_name='pps_1_7.JobInfo.pipeline_version', index=3,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parallelism_spec', full_name='pps_1_7.JobInfo.parallelism_spec', index=4,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='egress', full_name='pps_1_7.JobInfo.egress', index=5,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_job', full_name='pps_1_7.JobInfo.parent_job', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='started', full_name='pps_1_7.JobInfo.started', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='finished', full_name='pps_1_7.JobInfo.finished', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_commit', full_name='pps_1_7.JobInfo.output_commit', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='pps_1_7.JobInfo.state', index=10,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reason', full_name='pps_1_7.JobInfo.reason', index=11,
      number=35, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service', full_name='pps_1_7.JobInfo.service', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_repo', full_name='pps_1_7.JobInfo.output_repo', index=13,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_branch', full_name='pps_1_7.JobInfo.output_branch', index=14,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restart', full_name='pps_1_7.JobInfo.restart', index=15,
      number=20, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_processed', full_name='pps_1_7.JobInfo.data_processed', index=16,
      number=22, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_skipped', full_name='pps_1_7.JobInfo.data_skipped', index=17,
      number=30, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_failed', full_name='pps_1_7.JobInfo.data_failed', index=18,
      number=40, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_total', full_name='pps_1_7.JobInfo.data_total', index=19,
      number=23, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='pps_1_7.JobInfo.stats', index=20,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='worker_status', full_name='pps_1_7.JobInfo.worker_status', index=21,
      number=24, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_requests', full_name='pps_1_7.JobInfo.resource_requests', index=22,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_limits', full_name='pps_1_7.JobInfo.resource_limits', index=23,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input', full_name='pps_1_7.JobInfo.input', index=24,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_branch', full_name='pps_1_7.JobInfo.new_branch', index=25,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='incremental', full_name='pps_1_7.JobInfo.incremental', index=26,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats_commit', full_name='pps_1_7.JobInfo.stats_commit', index=27,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_stats', full_name='pps_1_7.JobInfo.enable_stats', index=28,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='salt', full_name='pps_1_7.JobInfo.salt', index=29,
      number=33, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch', full_name='pps_1_7.JobInfo.batch', index=30,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunk_spec', full_name='pps_1_7.JobInfo.chunk_spec', index=31,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datum_timeout', full_name='pps_1_7.JobInfo.datum_timeout', index=32,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_timeout', full_name='pps_1_7.JobInfo.job_timeout', index=33,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datum_tries', full_name='pps_1_7.JobInfo.datum_tries', index=34,
      number=41, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduling_spec', full_name='pps_1_7.JobInfo.scheduling_spec', index=35,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pod_spec', full_name='pps_1_7.JobInfo.pod_spec', index=36,
      number=43, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2853,
  serialized_end=4093,
)


_WORKER = _descriptor.Descriptor(
  name='Worker',
  full_name='pps_1_7.Worker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='pps_1_7.Worker.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='pps_1_7.Worker.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4095,
  serialized_end=4154,
)


_JOBINFOS = _descriptor.Descriptor(
  name='JobInfos',
  full_name='pps_1_7.JobInfos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_info', full_name='pps_1_7.JobInfos.job_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4156,
  serialized_end=4202,
)


_PIPELINE = _descriptor.Descriptor(
  name='Pipeline',
  full_name='pps_1_7.Pipeline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='pps_1_7.Pipeline.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4204,
  serialized_end=4228,
)


_PIPELINEINPUT = _descriptor.Descriptor(
  name='PipelineInput',
  full_name='pps_1_7.PipelineInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='pps_1_7.PipelineInput.name', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repo', full_name='pps_1_7.PipelineInput.repo', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='pps_1_7.PipelineInput.branch', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='glob', full_name='pps_1_7.PipelineInput.glob', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lazy', full_name='pps_1_7.PipelineInput.lazy', index=4,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='from', full_name='pps_1_7.PipelineInput.from', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4231,
  serialized_end=4364,
)


_ETCDPIPELINEINFO_JOBCOUNTSENTRY = _descriptor.Descriptor(
  name='JobCountsEntry',
  full_name='pps_1_7.EtcdPipelineInfo.JobCountsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='pps_1_7.EtcdPipelineInfo.JobCountsEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='pps_1_7.EtcdPipelineInfo.JobCountsEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4562,
  serialized_end=4610,
)

_ETCDPIPELINEINFO = _descriptor.Descriptor(
  name='EtcdPipelineInfo',
  full_name='pps_1_7.EtcdPipelineInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='pps_1_7.EtcdPipelineInfo.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reason', full_name='pps_1_7.EtcdPipelineInfo.reason', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec_commit', full_name='pps_1_7.EtcdPipelineInfo.spec_commit', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_counts', full_name='pps_1_7.EtcdPipelineInfo.job_counts', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_token', full_name='pps_1_7.EtcdPipelineInfo.auth_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ETCDPIPELINEINFO_JOBCOUNTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4367,
  serialized_end=4610,
)


_PIPELINEINFO_JOBCOUNTSENTRY = _descriptor.Descriptor(
  name='JobCountsEntry',
  full_name='pps_1_7.PipelineInfo.JobCountsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='pps_1_7.PipelineInfo.JobCountsEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='pps_1_7.PipelineInfo.JobCountsEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4562,
  serialized_end=4610,
)

_PIPELINEINFO = _descriptor.Descriptor(
  name='PipelineInfo',
  full_name='pps_1_7.PipelineInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='pps_1_7.PipelineInfo.id', index=0,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='pps_1_7.PipelineInfo.pipeline', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='pps_1_7.PipelineInfo.version', index=2,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transform', full_name='pps_1_7.PipelineInfo.transform', index=3,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parallelism_spec', full_name='pps_1_7.PipelineInfo.parallelism_spec', index=4,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hashtree_spec', full_name='pps_1_7.PipelineInfo.hashtree_spec', index=5,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='egress', full_name='pps_1_7.PipelineInfo.egress', index=6,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='pps_1_7.PipelineInfo.created_at', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='pps_1_7.PipelineInfo.state', index=8,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stopped', full_name='pps_1_7.PipelineInfo.stopped', index=9,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recent_error', full_name='pps_1_7.PipelineInfo.recent_error', index=10,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_counts', full_name='pps_1_7.PipelineInfo.job_counts', index=11,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_branch', full_name='pps_1_7.PipelineInfo.output_branch', index=12,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scale_down_threshold', full_name='pps_1_7.PipelineInfo.scale_down_threshold', index=13,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_requests', full_name='pps_1_7.PipelineInfo.resource_requests', index=14,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_limits', full_name='pps_1_7.PipelineInfo.resource_limits', index=15,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input', full_name='pps_1_7.PipelineInfo.input', index=16,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='pps_1_7.PipelineInfo.description', index=17,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='incremental', full_name='pps_1_7.PipelineInfo.incremental', index=18,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cache_size', full_name='pps_1_7.PipelineInfo.cache_size', index=19,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_stats', full_name='pps_1_7.PipelineInfo.enable_stats', index=20,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='salt', full_name='pps_1_7.PipelineInfo.salt', index=21,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch', full_name='pps_1_7.PipelineInfo.batch', index=22,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reason', full_name='pps_1_7.PipelineInfo.reason', index=23,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_queue_size', full_name='pps_1_7.PipelineInfo.max_queue_size', index=24,
      number=29, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service', full_name='pps_1_7.PipelineInfo.service', index=25,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunk_spec', full_name='pps_1_7.PipelineInfo.chunk_spec', index=26,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datum_timeout', full_name='pps_1_7.PipelineInfo.datum_timeout', index=27,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_timeout', full_name='pps_1_7.PipelineInfo.job_timeout', index=28,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='githook_url', full_name='pps_1_7.PipelineInfo.githook_url', index=29,
      number=35, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec_commit', full_name='pps_1_7.PipelineInfo.spec_commit', index=30,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='standby', full_name='pps_1_7.PipelineInfo.standby', index=31,
      number=37, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datum_tries', full_name='pps_1_7.PipelineInfo.datum_tries', index=32,
      number=39, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduling_spec', full_name='pps_1_7.PipelineInfo.scheduling_spec', index=33,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pod_spec', full_name='pps_1_7.PipelineInfo.pod_spec', index=34,
      number=41, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PIPELINEINFO_JOBCOUNTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4613,
  serialized_end=5815,
)


_PIPELINEINFOS = _descriptor.Descriptor(
  name='PipelineInfos',
  full_name='pps_1_7.PipelineInfos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline_info', full_name='pps_1_7.PipelineInfos.pipeline_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5817,
  serialized_end=5878,
)


_CREATEJOBREQUEST = _descriptor.Descriptor(
  name='CreateJobRequest',
  full_name='pps_1_7.CreateJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='pps_1_7.CreateJobRequest.pipeline', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_commit', full_name='pps_1_7.CreateJobRequest.output_commit', index=1,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5881,
  serialized_end=6102,
)


_INSPECTJOBREQUEST = _descriptor.Descriptor(
  name='InspectJobRequest',
  full_name='pps_1_7.InspectJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='pps_1_7.InspectJobRequest.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_commit', full_name='pps_1_7.InspectJobRequest.output_commit', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_state', full_name='pps_1_7.InspectJobRequest.block_state', index=2,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6104,
  serialized_end=6211,
)


_LISTJOBREQUEST = _descriptor.Descriptor(
  name='ListJobRequest',
  full_name='pps_1_7.ListJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='pps_1_7.ListJobRequest.pipeline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_commit', full_name='pps_1_7.ListJobRequest.input_commit', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_commit', full_name='pps_1_7.ListJobRequest.output_commit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6214,
  serialized_end=6346,
)


_FLUSHJOBREQUEST = _descriptor.Descriptor(
  name='FlushJobRequest',
  full_name='pps_1_7.FlushJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commits', full_name='pps_1_7.FlushJobRequest.commits', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to_pipelines', full_name='pps_1_7.FlushJobRequest.to_pipelines', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6348,
  serialized_end=6440,
)


_DELETEJOBREQUEST = _descriptor.Descriptor(
  name='DeleteJobRequest',
  full_name='pps_1_7.DeleteJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='pps_1_7.DeleteJobRequest.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6442,
  serialized_end=6487,
)


_STOPJOBREQUEST = _descriptor.Descriptor(
  name='StopJobRequest',
  full_name='pps_1_7.StopJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='pps_1_7.StopJobRequest.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6489,
  serialized_end=6532,
)


_GETLOGSREQUEST = _descriptor.Descriptor(
  name='GetLogsRequest',
  full_name='pps_1_7.GetLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='pps_1_7.GetLogsRequest.pipeline', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job', full_name='pps_1_7.GetLogsRequest.job', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_filters', full_name='pps_1_7.GetLogsRequest.data_filters', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datum', full_name='pps_1_7.GetLogsRequest.datum', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master', full_name='pps_1_7.GetLogsRequest.master', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='follow', full_name='pps_1_7.GetLogsRequest.follow', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tail', full_name='pps_1_7.GetLogsRequest.tail', index=6,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6535,
  serialized_end=6720,
)


_LOGMESSAGE = _descriptor.Descriptor(
  name='LogMessage',
  full_name='pps_1_7.LogMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline_name', full_name='pps_1_7.LogMessage.pipeline_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='pps_1_7.LogMessage.job_id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='worker_id', full_name='pps_1_7.LogMessage.worker_id', index=2,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datum_id', full_name='pps_1_7.LogMessage.datum_id', index=3,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master', full_name='pps_1_7.LogMessage.master', index=4,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='pps_1_7.LogMessage.data', index=5,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='pps_1_7.LogMessage.user', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ts', full_name='pps_1_7.LogMessage.ts', index=7,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='pps_1_7.LogMessage.message', index=8,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6723,
  serialized_end=6932,
)


_RESTARTDATUMREQUEST = _descriptor.Descriptor(
  name='RestartDatumRequest',
  full_name='pps_1_7.RestartDatumRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='pps_1_7.RestartDatumRequest.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_filters', full_name='pps_1_7.RestartDatumRequest.data_filters', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6934,
  serialized_end=7004,
)


_INSPECTDATUMREQUEST = _descriptor.Descriptor(
  name='InspectDatumRequest',
  full_name='pps_1_7.InspectDatumRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='datum', full_name='pps_1_7.InspectDatumRequest.datum', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7006,
  serialized_end=7058,
)


_LISTDATUMREQUEST = _descriptor.Descriptor(
  name='ListDatumRequest',
  full_name='pps_1_7.ListDatumRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='pps_1_7.ListDatumRequest.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='pps_1_7.ListDatumRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='pps_1_7.ListDatumRequest.page', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7060,
  serialized_end=7138,
)


_LISTDATUMRESPONSE = _descriptor.Descriptor(
  name='ListDatumResponse',
  full_name='pps_1_7.ListDatumResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='datum_infos', full_name='pps_1_7.ListDatumResponse.datum_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_pages', full_name='pps_1_7.ListDatumResponse.total_pages', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='pps_1_7.ListDatumResponse.page', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7140,
  serialized_end=7235,
)


_LISTDATUMSTREAMRESPONSE = _descriptor.Descriptor(
  name='ListDatumStreamResponse',
  full_name='pps_1_7.ListDatumStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='datum_info', full_name='pps_1_7.ListDatumStreamResponse.datum_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_pages', full_name='pps_1_7.ListDatumStreamResponse.total_pages', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='pps_1_7.ListDatumStreamResponse.page', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7237,
  serialized_end=7337,
)


_CHUNKSPEC = _descriptor.Descriptor(
  name='ChunkSpec',
  full_name='pps_1_7.ChunkSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='number', full_name='pps_1_7.ChunkSpec.number', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='pps_1_7.ChunkSpec.size_bytes', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7339,
  serialized_end=7386,
)


_SCHEDULINGSPEC_NODESELECTORENTRY = _descriptor.Descriptor(
  name='NodeSelectorEntry',
  full_name='pps_1_7.SchedulingSpec.NodeSelectorEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='pps_1_7.SchedulingSpec.NodeSelectorEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='pps_1_7.SchedulingSpec.NodeSelectorEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7502,
  serialized_end=7553,
)

_SCHEDULINGSPEC = _descriptor.Descriptor(
  name='SchedulingSpec',
  full_name='pps_1_7.SchedulingSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_selector', full_name='pps_1_7.SchedulingSpec.node_selector', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='priority_class_name', full_name='pps_1_7.SchedulingSpec.priority_class_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SCHEDULINGSPEC_NODESELECTORENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7389,
  serialized_end=7553,
)


_CREATEPIPELINEREQUEST = _descriptor.Descriptor(
  name='CreatePipelineRequest',
  full_name='pps_1_7.CreatePipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='pps_1_7.CreatePipelineRequest.pipeline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transform', full_name='pps_1_7.CreatePipelineRequest.transform', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parallelism_spec', full_name='pps_1_7.CreatePipelineRequest.parallelism_spec', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hashtree_spec', full_name='pps_1_7.CreatePipelineRequest.hashtree_spec', index=3,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='egress', full_name='pps_1_7.CreatePipelineRequest.egress', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='pps_1_7.CreatePipelineRequest.update', index=5,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_branch', full_name='pps_1_7.CreatePipelineRequest.output_branch', index=6,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scale_down_threshold', full_name='pps_1_7.CreatePipelineRequest.scale_down_threshold', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_requests', full_name='pps_1_7.CreatePipelineRequest.resource_requests', index=8,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_limits', full_name='pps_1_7.CreatePipelineRequest.resource_limits', index=9,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input', full_name='pps_1_7.CreatePipelineRequest.input', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='pps_1_7.CreatePipelineRequest.description', index=11,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='incremental', full_name='pps_1_7.CreatePipelineRequest.incremental', index=12,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cache_size', full_name='pps_1_7.CreatePipelineRequest.cache_size', index=13,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_stats', full_name='pps_1_7.CreatePipelineRequest.enable_stats', index=14,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reprocess', full_name='pps_1_7.CreatePipelineRequest.reprocess', index=15,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch', full_name='pps_1_7.CreatePipelineRequest.batch', index=16,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_queue_size', full_name='pps_1_7.CreatePipelineRequest.max_queue_size', index=17,
      number=20, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service', full_name='pps_1_7.CreatePipelineRequest.service', index=18,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunk_spec', full_name='pps_1_7.CreatePipelineRequest.chunk_spec', index=19,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datum_timeout', full_name='pps_1_7.CreatePipelineRequest.datum_timeout', index=20,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_timeout', full_name='pps_1_7.CreatePipelineRequest.job_timeout', index=21,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='salt', full_name='pps_1_7.CreatePipelineRequest.salt', index=22,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='standby', full_name='pps_1_7.CreatePipelineRequest.standby', index=23,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datum_tries', full_name='pps_1_7.CreatePipelineRequest.datum_tries', index=24,
      number=28, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduling_spec', full_name='pps_1_7.CreatePipelineRequest.scheduling_spec', index=25,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pod_spec', full_name='pps_1_7.CreatePipelineRequest.pod_spec', index=26,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7556,
  serialized_end=8458,
)


_INSPECTPIPELINEREQUEST = _descriptor.Descriptor(
  name='InspectPipelineRequest',
  full_name='pps_1_7.InspectPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='pps_1_7.InspectPipelineRequest.pipeline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8460,
  serialized_end=8521,
)


_LISTPIPELINEREQUEST = _descriptor.Descriptor(
  name='ListPipelineRequest',
  full_name='pps_1_7.ListPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8523,
  serialized_end=8544,
)


_DELETEPIPELINEREQUEST = _descriptor.Descriptor(
  name='DeletePipelineRequest',
  full_name='pps_1_7.DeletePipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='pps_1_7.DeletePipelineRequest.pipeline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all', full_name='pps_1_7.DeletePipelineRequest.all', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force', full_name='pps_1_7.DeletePipelineRequest.force', index=2,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8546,
  serialized_end=8646,
)


_STARTPIPELINEREQUEST = _descriptor.Descriptor(
  name='StartPipelineRequest',
  full_name='pps_1_7.StartPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='pps_1_7.StartPipelineRequest.pipeline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8648,
  serialized_end=8707,
)


_STOPPIPELINEREQUEST = _descriptor.Descriptor(
  name='StopPipelineRequest',
  full_name='pps_1_7.StopPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='pps_1_7.StopPipelineRequest.pipeline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8709,
  serialized_end=8767,
)


_RERUNPIPELINEREQUEST = _descriptor.Descriptor(
  name='RerunPipelineRequest',
  full_name='pps_1_7.RerunPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='pps_1_7.RerunPipelineRequest.pipeline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exclude', full_name='pps_1_7.RerunPipelineRequest.exclude', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='include', full_name='pps_1_7.RerunPipelineRequest.include', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8769,
  serialized_end=8896,
)


_GARBAGECOLLECTREQUEST = _descriptor.Descriptor(
  name='GarbageCollectRequest',
  full_name='pps_1_7.GarbageCollectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='memory_bytes', full_name='pps_1_7.GarbageCollectRequest.memory_bytes', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8898,
  serialized_end=8943,
)


_GARBAGECOLLECTRESPONSE = _descriptor.Descriptor(
  name='GarbageCollectResponse',
  full_name='pps_1_7.GarbageCollectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8945,
  serialized_end=8969,
)


_ACTIVATEAUTHREQUEST = _descriptor.Descriptor(
  name='ActivateAuthRequest',
  full_name='pps_1_7.ActivateAuthRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8971,
  serialized_end=8992,
)


_ACTIVATEAUTHRESPONSE = _descriptor.Descriptor(
  name='ActivateAuthResponse',
  full_name='pps_1_7.ActivateAuthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8994,
  serialized_end=9016,
)

_TRANSFORM_ENVENTRY.containing_type = _TRANSFORM
_TRANSFORM.fields_by_name['env'].message_type = _TRANSFORM_ENVENTRY
_TRANSFORM.fields_by_name['secrets'].message_type = _SECRET
_CRONINPUT.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INPUT.fields_by_name['atom'].message_type = _ATOMINPUT
_INPUT.fields_by_name['cross'].message_type = _INPUT
_INPUT.fields_by_name['union'].message_type = _INPUT
_INPUT.fields_by_name['cron'].message_type = _CRONINPUT
_INPUT.fields_by_name['git'].message_type = _GITINPUT
_JOBINPUT.fields_by_name['commit'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._COMMIT
_DATUM.fields_by_name['job'].message_type = _JOB
_DATUMINFO.fields_by_name['datum'].message_type = _DATUM
_DATUMINFO.fields_by_name['state'].enum_type = _DATUMSTATE
_DATUMINFO.fields_by_name['stats'].message_type = _PROCESSSTATS
_DATUMINFO.fields_by_name['pfs_state'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._FILE
_DATUMINFO.fields_by_name['data'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._FILEINFO
_PROCESSSTATS.fields_by_name['download_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_PROCESSSTATS.fields_by_name['process_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_PROCESSSTATS.fields_by_name['upload_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_AGGREGATEPROCESSSTATS.fields_by_name['download_time'].message_type = _AGGREGATE
_AGGREGATEPROCESSSTATS.fields_by_name['process_time'].message_type = _AGGREGATE
_AGGREGATEPROCESSSTATS.fields_by_name['upload_time'].message_type = _AGGREGATE
_AGGREGATEPROCESSSTATS.fields_by_name['download_bytes'].message_type = _AGGREGATE
_AGGREGATEPROCESSSTATS.fields_by_name['upload_bytes'].message_type = _AGGREGATE
_WORKERSTATUS.fields_by_name['data'].message_type = _INPUTFILE
_WORKERSTATUS.fields_by_name['started'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WORKERSTATUS.fields_by_name['stats'].message_type = _PROCESSSTATS
_ETCDJOBINFO.fields_by_name['job'].message_type = _JOB
_ETCDJOBINFO.fields_by_name['pipeline'].message_type = _PIPELINE
_ETCDJOBINFO.fields_by_name['output_commit'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._COMMIT
_ETCDJOBINFO.fields_by_name['stats'].message_type = _PROCESSSTATS
_ETCDJOBINFO.fields_by_name['stats_commit'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._COMMIT
_ETCDJOBINFO.fields_by_name['state'].enum_type = _JOBSTATE
_ETCDJOBINFO.fields_by_name['started'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ETCDJOBINFO.fields_by_name['finished'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBINFO.fields_by_name['job'].message_type = _JOB
_JOBINFO.fields_by_name['transform'].message_type = _TRANSFORM
_JOBINFO.fields_by_name['pipeline'].message_type = _PIPELINE
_JOBINFO.fields_by_name['parallelism_spec'].message_type = _PARALLELISMSPEC
_JOBINFO.fields_by_name['egress'].message_type = _EGRESS
_JOBINFO.fields_by_name['parent_job'].message_type = _JOB
_JOBINFO.fields_by_name['started'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBINFO.fields_by_name['finished'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBINFO.fields_by_name['output_commit'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._COMMIT
_JOBINFO.fields_by_name['state'].enum_type = _JOBSTATE
_JOBINFO.fields_by_name['service'].message_type = _SERVICE
_JOBINFO.fields_by_name['output_repo'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._REPO
_JOBINFO.fields_by_name['stats'].message_type = _PROCESSSTATS
_JOBINFO.fields_by_name['worker_status'].message_type = _WORKERSTATUS
_JOBINFO.fields_by_name['resource_requests'].message_type = _RESOURCESPEC
_JOBINFO.fields_by_name['resource_limits'].message_type = _RESOURCESPEC
_JOBINFO.fields_by_name['input'].message_type = _INPUT
_JOBINFO.fields_by_name['new_branch'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._BRANCHINFO
_JOBINFO.fields_by_name['stats_commit'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._COMMIT
_JOBINFO.fields_by_name['chunk_spec'].message_type = _CHUNKSPEC
_JOBINFO.fields_by_name['datum_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_JOBINFO.fields_by_name['job_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_JOBINFO.fields_by_name['scheduling_spec'].message_type = _SCHEDULINGSPEC
_WORKER.fields_by_name['state'].enum_type = _WORKERSTATE
_JOBINFOS.fields_by_name['job_info'].message_type = _JOBINFO
_PIPELINEINPUT.fields_by_name['repo'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._REPO
_PIPELINEINPUT.fields_by_name['from'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._COMMIT
_ETCDPIPELINEINFO_JOBCOUNTSENTRY.containing_type = _ETCDPIPELINEINFO
_ETCDPIPELINEINFO.fields_by_name['state'].enum_type = _PIPELINESTATE
_ETCDPIPELINEINFO.fields_by_name['spec_commit'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._COMMIT
_ETCDPIPELINEINFO.fields_by_name['job_counts'].message_type = _ETCDPIPELINEINFO_JOBCOUNTSENTRY
_PIPELINEINFO_JOBCOUNTSENTRY.containing_type = _PIPELINEINFO
_PIPELINEINFO.fields_by_name['pipeline'].message_type = _PIPELINE
_PIPELINEINFO.fields_by_name['transform'].message_type = _TRANSFORM
_PIPELINEINFO.fields_by_name['parallelism_spec'].message_type = _PARALLELISMSPEC
_PIPELINEINFO.fields_by_name['hashtree_spec'].message_type = _HASHTREESPEC
_PIPELINEINFO.fields_by_name['egress'].message_type = _EGRESS
_PIPELINEINFO.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PIPELINEINFO.fields_by_name['state'].enum_type = _PIPELINESTATE
_PIPELINEINFO.fields_by_name['job_counts'].message_type = _PIPELINEINFO_JOBCOUNTSENTRY
_PIPELINEINFO.fields_by_name['scale_down_threshold'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_PIPELINEINFO.fields_by_name['resource_requests'].message_type = _RESOURCESPEC
_PIPELINEINFO.fields_by_name['resource_limits'].message_type = _RESOURCESPEC
_PIPELINEINFO.fields_by_name['input'].message_type = _INPUT
_PIPELINEINFO.fields_by_name['service'].message_type = _SERVICE
_PIPELINEINFO.fields_by_name['chunk_spec'].message_type = _CHUNKSPEC
_PIPELINEINFO.fields_by_name['datum_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_PIPELINEINFO.fields_by_name['job_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_PIPELINEINFO.fields_by_name['spec_commit'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._COMMIT
_PIPELINEINFO.fields_by_name['scheduling_spec'].message_type = _SCHEDULINGSPEC
_PIPELINEINFOS.fields_by_name['pipeline_info'].message_type = _PIPELINEINFO
_CREATEJOBREQUEST.fields_by_name['pipeline'].message_type = _PIPELINE
_CREATEJOBREQUEST.fields_by_name['output_commit'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._COMMIT
_INSPECTJOBREQUEST.fields_by_name['job'].message_type = _JOB
_INSPECTJOBREQUEST.fields_by_name['output_commit'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._COMMIT
_LISTJOBREQUEST.fields_by_name['pipeline'].message_type = _PIPELINE
_LISTJOBREQUEST.fields_by_name['input_commit'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._COMMIT
_LISTJOBREQUEST.fields_by_name['output_commit'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._COMMIT
_FLUSHJOBREQUEST.fields_by_name['commits'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._COMMIT
_FLUSHJOBREQUEST.fields_by_name['to_pipelines'].message_type = _PIPELINE
_DELETEJOBREQUEST.fields_by_name['job'].message_type = _JOB
_STOPJOBREQUEST.fields_by_name['job'].message_type = _JOB
_GETLOGSREQUEST.fields_by_name['pipeline'].message_type = _PIPELINE
_GETLOGSREQUEST.fields_by_name['job'].message_type = _JOB
_GETLOGSREQUEST.fields_by_name['datum'].message_type = _DATUM
_LOGMESSAGE.fields_by_name['data'].message_type = _INPUTFILE
_LOGMESSAGE.fields_by_name['ts'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RESTARTDATUMREQUEST.fields_by_name['job'].message_type = _JOB
_INSPECTDATUMREQUEST.fields_by_name['datum'].message_type = _DATUM
_LISTDATUMREQUEST.fields_by_name['job'].message_type = _JOB
_LISTDATUMRESPONSE.fields_by_name['datum_infos'].message_type = _DATUMINFO
_LISTDATUMSTREAMRESPONSE.fields_by_name['datum_info'].message_type = _DATUMINFO
_SCHEDULINGSPEC_NODESELECTORENTRY.containing_type = _SCHEDULINGSPEC
_SCHEDULINGSPEC.fields_by_name['node_selector'].message_type = _SCHEDULINGSPEC_NODESELECTORENTRY
_CREATEPIPELINEREQUEST.fields_by_name['pipeline'].message_type = _PIPELINE
_CREATEPIPELINEREQUEST.fields_by_name['transform'].message_type = _TRANSFORM
_CREATEPIPELINEREQUEST.fields_by_name['parallelism_spec'].message_type = _PARALLELISMSPEC
_CREATEPIPELINEREQUEST.fields_by_name['hashtree_spec'].message_type = _HASHTREESPEC
_CREATEPIPELINEREQUEST.fields_by_name['egress'].message_type = _EGRESS
_CREATEPIPELINEREQUEST.fields_by_name['scale_down_threshold'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CREATEPIPELINEREQUEST.fields_by_name['resource_requests'].message_type = _RESOURCESPEC
_CREATEPIPELINEREQUEST.fields_by_name['resource_limits'].message_type = _RESOURCESPEC
_CREATEPIPELINEREQUEST.fields_by_name['input'].message_type = _INPUT
_CREATEPIPELINEREQUEST.fields_by_name['service'].message_type = _SERVICE
_CREATEPIPELINEREQUEST.fields_by_name['chunk_spec'].message_type = _CHUNKSPEC
_CREATEPIPELINEREQUEST.fields_by_name['datum_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CREATEPIPELINEREQUEST.fields_by_name['job_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CREATEPIPELINEREQUEST.fields_by_name['scheduling_spec'].message_type = _SCHEDULINGSPEC
_INSPECTPIPELINEREQUEST.fields_by_name['pipeline'].message_type = _PIPELINE
_DELETEPIPELINEREQUEST.fields_by_name['pipeline'].message_type = _PIPELINE
_STARTPIPELINEREQUEST.fields_by_name['pipeline'].message_type = _PIPELINE
_STOPPIPELINEREQUEST.fields_by_name['pipeline'].message_type = _PIPELINE
_RERUNPIPELINEREQUEST.fields_by_name['pipeline'].message_type = _PIPELINE
_RERUNPIPELINEREQUEST.fields_by_name['exclude'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._COMMIT
_RERUNPIPELINEREQUEST.fields_by_name['include'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._COMMIT
DESCRIPTOR.message_types_by_name['Secret'] = _SECRET
DESCRIPTOR.message_types_by_name['Transform'] = _TRANSFORM
DESCRIPTOR.message_types_by_name['Egress'] = _EGRESS
DESCRIPTOR.message_types_by_name['Job'] = _JOB
DESCRIPTOR.message_types_by_name['Service'] = _SERVICE
DESCRIPTOR.message_types_by_name['AtomInput'] = _ATOMINPUT
DESCRIPTOR.message_types_by_name['CronInput'] = _CRONINPUT
DESCRIPTOR.message_types_by_name['GitInput'] = _GITINPUT
DESCRIPTOR.message_types_by_name['Input'] = _INPUT
DESCRIPTOR.message_types_by_name['JobInput'] = _JOBINPUT
DESCRIPTOR.message_types_by_name['ParallelismSpec'] = _PARALLELISMSPEC
DESCRIPTOR.message_types_by_name['HashtreeSpec'] = _HASHTREESPEC
DESCRIPTOR.message_types_by_name['InputFile'] = _INPUTFILE
DESCRIPTOR.message_types_by_name['Datum'] = _DATUM
DESCRIPTOR.message_types_by_name['DatumInfo'] = _DATUMINFO
DESCRIPTOR.message_types_by_name['Aggregate'] = _AGGREGATE
DESCRIPTOR.message_types_by_name['ProcessStats'] = _PROCESSSTATS
DESCRIPTOR.message_types_by_name['AggregateProcessStats'] = _AGGREGATEPROCESSSTATS
DESCRIPTOR.message_types_by_name['WorkerStatus'] = _WORKERSTATUS
DESCRIPTOR.message_types_by_name['ResourceSpec'] = _RESOURCESPEC
DESCRIPTOR.message_types_by_name['EtcdJobInfo'] = _ETCDJOBINFO
DESCRIPTOR.message_types_by_name['JobInfo'] = _JOBINFO
DESCRIPTOR.message_types_by_name['Worker'] = _WORKER
DESCRIPTOR.message_types_by_name['JobInfos'] = _JOBINFOS
DESCRIPTOR.message_types_by_name['Pipeline'] = _PIPELINE
DESCRIPTOR.message_types_by_name['PipelineInput'] = _PIPELINEINPUT
DESCRIPTOR.message_types_by_name['EtcdPipelineInfo'] = _ETCDPIPELINEINFO
DESCRIPTOR.message_types_by_name['PipelineInfo'] = _PIPELINEINFO
DESCRIPTOR.message_types_by_name['PipelineInfos'] = _PIPELINEINFOS
DESCRIPTOR.message_types_by_name['CreateJobRequest'] = _CREATEJOBREQUEST
DESCRIPTOR.message_types_by_name['InspectJobRequest'] = _INSPECTJOBREQUEST
DESCRIPTOR.message_types_by_name['ListJobRequest'] = _LISTJOBREQUEST
DESCRIPTOR.message_types_by_name['FlushJobRequest'] = _FLUSHJOBREQUEST
DESCRIPTOR.message_types_by_name['DeleteJobRequest'] = _DELETEJOBREQUEST
DESCRIPTOR.message_types_by_name['StopJobRequest'] = _STOPJOBREQUEST
DESCRIPTOR.message_types_by_name['GetLogsRequest'] = _GETLOGSREQUEST
DESCRIPTOR.message_types_by_name['LogMessage'] = _LOGMESSAGE
DESCRIPTOR.message_types_by_name['RestartDatumRequest'] = _RESTARTDATUMREQUEST
DESCRIPTOR.message_types_by_name['InspectDatumRequest'] = _INSPECTDATUMREQUEST
DESCRIPTOR.message_types_by_name['ListDatumRequest'] = _LISTDATUMREQUEST
DESCRIPTOR.message_types_by_name['ListDatumResponse'] = _LISTDATUMRESPONSE
DESCRIPTOR.message_types_by_name['ListDatumStreamResponse'] = _LISTDATUMSTREAMRESPONSE
DESCRIPTOR.message_types_by_name['ChunkSpec'] = _CHUNKSPEC
DESCRIPTOR.message_types_by_name['SchedulingSpec'] = _SCHEDULINGSPEC
DESCRIPTOR.message_types_by_name['CreatePipelineRequest'] = _CREATEPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['InspectPipelineRequest'] = _INSPECTPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['ListPipelineRequest'] = _LISTPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['DeletePipelineRequest'] = _DELETEPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['StartPipelineRequest'] = _STARTPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['StopPipelineRequest'] = _STOPPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['RerunPipelineRequest'] = _RERUNPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['GarbageCollectRequest'] = _GARBAGECOLLECTREQUEST
DESCRIPTOR.message_types_by_name['GarbageCollectResponse'] = _GARBAGECOLLECTRESPONSE
DESCRIPTOR.message_types_by_name['ActivateAuthRequest'] = _ACTIVATEAUTHREQUEST
DESCRIPTOR.message_types_by_name['ActivateAuthResponse'] = _ACTIVATEAUTHRESPONSE
DESCRIPTOR.enum_types_by_name['JobState'] = _JOBSTATE
DESCRIPTOR.enum_types_by_name['DatumState'] = _DATUMSTATE
DESCRIPTOR.enum_types_by_name['WorkerState'] = _WORKERSTATE
DESCRIPTOR.enum_types_by_name['PipelineState'] = _PIPELINESTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Secret = _reflection.GeneratedProtocolMessageType('Secret', (_message.Message,), {
  'DESCRIPTOR' : _SECRET,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.Secret)
  })
_sym_db.RegisterMessage(Secret)

Transform = _reflection.GeneratedProtocolMessageType('Transform', (_message.Message,), {

  'EnvEntry' : _reflection.GeneratedProtocolMessageType('EnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_ENVENTRY,
    '__module__' : 'client.admin.v1_7.pps.pps_pb2'
    # @@protoc_insertion_point(class_scope:pps_1_7.Transform.EnvEntry)
    })
  ,
  'DESCRIPTOR' : _TRANSFORM,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.Transform)
  })
_sym_db.RegisterMessage(Transform)
_sym_db.RegisterMessage(Transform.EnvEntry)

Egress = _reflection.GeneratedProtocolMessageType('Egress', (_message.Message,), {
  'DESCRIPTOR' : _EGRESS,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.Egress)
  })
_sym_db.RegisterMessage(Egress)

Job = _reflection.GeneratedProtocolMessageType('Job', (_message.Message,), {
  'DESCRIPTOR' : _JOB,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.Job)
  })
_sym_db.RegisterMessage(Job)

Service = _reflection.GeneratedProtocolMessageType('Service', (_message.Message,), {
  'DESCRIPTOR' : _SERVICE,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.Service)
  })
_sym_db.RegisterMessage(Service)

AtomInput = _reflection.GeneratedProtocolMessageType('AtomInput', (_message.Message,), {
  'DESCRIPTOR' : _ATOMINPUT,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.AtomInput)
  })
_sym_db.RegisterMessage(AtomInput)

CronInput = _reflection.GeneratedProtocolMessageType('CronInput', (_message.Message,), {
  'DESCRIPTOR' : _CRONINPUT,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.CronInput)
  })
_sym_db.RegisterMessage(CronInput)

GitInput = _reflection.GeneratedProtocolMessageType('GitInput', (_message.Message,), {
  'DESCRIPTOR' : _GITINPUT,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.GitInput)
  })
_sym_db.RegisterMessage(GitInput)

Input = _reflection.GeneratedProtocolMessageType('Input', (_message.Message,), {
  'DESCRIPTOR' : _INPUT,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.Input)
  })
_sym_db.RegisterMessage(Input)

JobInput = _reflection.GeneratedProtocolMessageType('JobInput', (_message.Message,), {
  'DESCRIPTOR' : _JOBINPUT,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.JobInput)
  })
_sym_db.RegisterMessage(JobInput)

ParallelismSpec = _reflection.GeneratedProtocolMessageType('ParallelismSpec', (_message.Message,), {
  'DESCRIPTOR' : _PARALLELISMSPEC,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.ParallelismSpec)
  })
_sym_db.RegisterMessage(ParallelismSpec)

HashtreeSpec = _reflection.GeneratedProtocolMessageType('HashtreeSpec', (_message.Message,), {
  'DESCRIPTOR' : _HASHTREESPEC,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.HashtreeSpec)
  })
_sym_db.RegisterMessage(HashtreeSpec)

InputFile = _reflection.GeneratedProtocolMessageType('InputFile', (_message.Message,), {
  'DESCRIPTOR' : _INPUTFILE,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.InputFile)
  })
_sym_db.RegisterMessage(InputFile)

Datum = _reflection.GeneratedProtocolMessageType('Datum', (_message.Message,), {
  'DESCRIPTOR' : _DATUM,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.Datum)
  })
_sym_db.RegisterMessage(Datum)

DatumInfo = _reflection.GeneratedProtocolMessageType('DatumInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATUMINFO,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.DatumInfo)
  })
_sym_db.RegisterMessage(DatumInfo)

Aggregate = _reflection.GeneratedProtocolMessageType('Aggregate', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATE,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.Aggregate)
  })
_sym_db.RegisterMessage(Aggregate)

ProcessStats = _reflection.GeneratedProtocolMessageType('ProcessStats', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSSTATS,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.ProcessStats)
  })
_sym_db.RegisterMessage(ProcessStats)

AggregateProcessStats = _reflection.GeneratedProtocolMessageType('AggregateProcessStats', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATEPROCESSSTATS,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.AggregateProcessStats)
  })
_sym_db.RegisterMessage(AggregateProcessStats)

WorkerStatus = _reflection.GeneratedProtocolMessageType('WorkerStatus', (_message.Message,), {
  'DESCRIPTOR' : _WORKERSTATUS,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.WorkerStatus)
  })
_sym_db.RegisterMessage(WorkerStatus)

ResourceSpec = _reflection.GeneratedProtocolMessageType('ResourceSpec', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESPEC,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.ResourceSpec)
  })
_sym_db.RegisterMessage(ResourceSpec)

EtcdJobInfo = _reflection.GeneratedProtocolMessageType('EtcdJobInfo', (_message.Message,), {
  'DESCRIPTOR' : _ETCDJOBINFO,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.EtcdJobInfo)
  })
_sym_db.RegisterMessage(EtcdJobInfo)

JobInfo = _reflection.GeneratedProtocolMessageType('JobInfo', (_message.Message,), {
  'DESCRIPTOR' : _JOBINFO,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.JobInfo)
  })
_sym_db.RegisterMessage(JobInfo)

Worker = _reflection.GeneratedProtocolMessageType('Worker', (_message.Message,), {
  'DESCRIPTOR' : _WORKER,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.Worker)
  })
_sym_db.RegisterMessage(Worker)

JobInfos = _reflection.GeneratedProtocolMessageType('JobInfos', (_message.Message,), {
  'DESCRIPTOR' : _JOBINFOS,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.JobInfos)
  })
_sym_db.RegisterMessage(JobInfos)

Pipeline = _reflection.GeneratedProtocolMessageType('Pipeline', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINE,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.Pipeline)
  })
_sym_db.RegisterMessage(Pipeline)

PipelineInput = _reflection.GeneratedProtocolMessageType('PipelineInput', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINEINPUT,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.PipelineInput)
  })
_sym_db.RegisterMessage(PipelineInput)

EtcdPipelineInfo = _reflection.GeneratedProtocolMessageType('EtcdPipelineInfo', (_message.Message,), {

  'JobCountsEntry' : _reflection.GeneratedProtocolMessageType('JobCountsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ETCDPIPELINEINFO_JOBCOUNTSENTRY,
    '__module__' : 'client.admin.v1_7.pps.pps_pb2'
    # @@protoc_insertion_point(class_scope:pps_1_7.EtcdPipelineInfo.JobCountsEntry)
    })
  ,
  'DESCRIPTOR' : _ETCDPIPELINEINFO,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.EtcdPipelineInfo)
  })
_sym_db.RegisterMessage(EtcdPipelineInfo)
_sym_db.RegisterMessage(EtcdPipelineInfo.JobCountsEntry)

PipelineInfo = _reflection.GeneratedProtocolMessageType('PipelineInfo', (_message.Message,), {

  'JobCountsEntry' : _reflection.GeneratedProtocolMessageType('JobCountsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PIPELINEINFO_JOBCOUNTSENTRY,
    '__module__' : 'client.admin.v1_7.pps.pps_pb2'
    # @@protoc_insertion_point(class_scope:pps_1_7.PipelineInfo.JobCountsEntry)
    })
  ,
  'DESCRIPTOR' : _PIPELINEINFO,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.PipelineInfo)
  })
_sym_db.RegisterMessage(PipelineInfo)
_sym_db.RegisterMessage(PipelineInfo.JobCountsEntry)

PipelineInfos = _reflection.GeneratedProtocolMessageType('PipelineInfos', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINEINFOS,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.PipelineInfos)
  })
_sym_db.RegisterMessage(PipelineInfos)

CreateJobRequest = _reflection.GeneratedProtocolMessageType('CreateJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEJOBREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.CreateJobRequest)
  })
_sym_db.RegisterMessage(CreateJobRequest)

InspectJobRequest = _reflection.GeneratedProtocolMessageType('InspectJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSPECTJOBREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.InspectJobRequest)
  })
_sym_db.RegisterMessage(InspectJobRequest)

ListJobRequest = _reflection.GeneratedProtocolMessageType('ListJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.ListJobRequest)
  })
_sym_db.RegisterMessage(ListJobRequest)

FlushJobRequest = _reflection.GeneratedProtocolMessageType('FlushJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _FLUSHJOBREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.FlushJobRequest)
  })
_sym_db.RegisterMessage(FlushJobRequest)

DeleteJobRequest = _reflection.GeneratedProtocolMessageType('DeleteJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEJOBREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.DeleteJobRequest)
  })
_sym_db.RegisterMessage(DeleteJobRequest)

StopJobRequest = _reflection.GeneratedProtocolMessageType('StopJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPJOBREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.StopJobRequest)
  })
_sym_db.RegisterMessage(StopJobRequest)

GetLogsRequest = _reflection.GeneratedProtocolMessageType('GetLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLOGSREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.GetLogsRequest)
  })
_sym_db.RegisterMessage(GetLogsRequest)

LogMessage = _reflection.GeneratedProtocolMessageType('LogMessage', (_message.Message,), {
  'DESCRIPTOR' : _LOGMESSAGE,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.LogMessage)
  })
_sym_db.RegisterMessage(LogMessage)

RestartDatumRequest = _reflection.GeneratedProtocolMessageType('RestartDatumRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTDATUMREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.RestartDatumRequest)
  })
_sym_db.RegisterMessage(RestartDatumRequest)

InspectDatumRequest = _reflection.GeneratedProtocolMessageType('InspectDatumRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSPECTDATUMREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.InspectDatumRequest)
  })
_sym_db.RegisterMessage(InspectDatumRequest)

ListDatumRequest = _reflection.GeneratedProtocolMessageType('ListDatumRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATUMREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.ListDatumRequest)
  })
_sym_db.RegisterMessage(ListDatumRequest)

ListDatumResponse = _reflection.GeneratedProtocolMessageType('ListDatumResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATUMRESPONSE,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.ListDatumResponse)
  })
_sym_db.RegisterMessage(ListDatumResponse)

ListDatumStreamResponse = _reflection.GeneratedProtocolMessageType('ListDatumStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATUMSTREAMRESPONSE,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.ListDatumStreamResponse)
  })
_sym_db.RegisterMessage(ListDatumStreamResponse)

ChunkSpec = _reflection.GeneratedProtocolMessageType('ChunkSpec', (_message.Message,), {
  'DESCRIPTOR' : _CHUNKSPEC,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.ChunkSpec)
  })
_sym_db.RegisterMessage(ChunkSpec)

SchedulingSpec = _reflection.GeneratedProtocolMessageType('SchedulingSpec', (_message.Message,), {

  'NodeSelectorEntry' : _reflection.GeneratedProtocolMessageType('NodeSelectorEntry', (_message.Message,), {
    'DESCRIPTOR' : _SCHEDULINGSPEC_NODESELECTORENTRY,
    '__module__' : 'client.admin.v1_7.pps.pps_pb2'
    # @@protoc_insertion_point(class_scope:pps_1_7.SchedulingSpec.NodeSelectorEntry)
    })
  ,
  'DESCRIPTOR' : _SCHEDULINGSPEC,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.SchedulingSpec)
  })
_sym_db.RegisterMessage(SchedulingSpec)
_sym_db.RegisterMessage(SchedulingSpec.NodeSelectorEntry)

CreatePipelineRequest = _reflection.GeneratedProtocolMessageType('CreatePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPIPELINEREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.CreatePipelineRequest)
  })
_sym_db.RegisterMessage(CreatePipelineRequest)

InspectPipelineRequest = _reflection.GeneratedProtocolMessageType('InspectPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSPECTPIPELINEREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.InspectPipelineRequest)
  })
_sym_db.RegisterMessage(InspectPipelineRequest)

ListPipelineRequest = _reflection.GeneratedProtocolMessageType('ListPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPIPELINEREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.ListPipelineRequest)
  })
_sym_db.RegisterMessage(ListPipelineRequest)

DeletePipelineRequest = _reflection.GeneratedProtocolMessageType('DeletePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPIPELINEREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.DeletePipelineRequest)
  })
_sym_db.RegisterMessage(DeletePipelineRequest)

StartPipelineRequest = _reflection.GeneratedProtocolMessageType('StartPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTPIPELINEREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.StartPipelineRequest)
  })
_sym_db.RegisterMessage(StartPipelineRequest)

StopPipelineRequest = _reflection.GeneratedProtocolMessageType('StopPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPPIPELINEREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.StopPipelineRequest)
  })
_sym_db.RegisterMessage(StopPipelineRequest)

RerunPipelineRequest = _reflection.GeneratedProtocolMessageType('RerunPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RERUNPIPELINEREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.RerunPipelineRequest)
  })
_sym_db.RegisterMessage(RerunPipelineRequest)

GarbageCollectRequest = _reflection.GeneratedProtocolMessageType('GarbageCollectRequest', (_message.Message,), {
  'DESCRIPTOR' : _GARBAGECOLLECTREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.GarbageCollectRequest)
  })
_sym_db.RegisterMessage(GarbageCollectRequest)

GarbageCollectResponse = _reflection.GeneratedProtocolMessageType('GarbageCollectResponse', (_message.Message,), {
  'DESCRIPTOR' : _GARBAGECOLLECTRESPONSE,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.GarbageCollectResponse)
  })
_sym_db.RegisterMessage(GarbageCollectResponse)

ActivateAuthRequest = _reflection.GeneratedProtocolMessageType('ActivateAuthRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEAUTHREQUEST,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.ActivateAuthRequest)
  })
_sym_db.RegisterMessage(ActivateAuthRequest)

ActivateAuthResponse = _reflection.GeneratedProtocolMessageType('ActivateAuthResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEAUTHRESPONSE,
  '__module__' : 'client.admin.v1_7.pps.pps_pb2'
  # @@protoc_insertion_point(class_scope:pps_1_7.ActivateAuthResponse)
  })
_sym_db.RegisterMessage(ActivateAuthResponse)


DESCRIPTOR._options = None
_TRANSFORM_ENVENTRY._options = None
_ETCDPIPELINEINFO_JOBCOUNTSENTRY._options = None
_PIPELINEINFO_JOBCOUNTSENTRY._options = None
_SCHEDULINGSPEC_NODESELECTORENTRY._options = None

_API = _descriptor.ServiceDescriptor(
  name='API',
  full_name='pps_1_7.API',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=9400,
  serialized_end=10935,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateJob',
    full_name='pps_1_7.API.CreateJob',
    index=0,
    containing_service=None,
    input_type=_CREATEJOBREQUEST,
    output_type=_JOB,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InspectJob',
    full_name='pps_1_7.API.InspectJob',
    index=1,
    containing_service=None,
    input_type=_INSPECTJOBREQUEST,
    output_type=_JOBINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListJob',
    full_name='pps_1_7.API.ListJob',
    index=2,
    containing_service=None,
    input_type=_LISTJOBREQUEST,
    output_type=_JOBINFOS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListJobStream',
    full_name='pps_1_7.API.ListJobStream',
    index=3,
    containing_service=None,
    input_type=_LISTJOBREQUEST,
    output_type=_JOBINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FlushJob',
    full_name='pps_1_7.API.FlushJob',
    index=4,
    containing_service=None,
    input_type=_FLUSHJOBREQUEST,
    output_type=_JOBINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteJob',
    full_name='pps_1_7.API.DeleteJob',
    index=5,
    containing_service=None,
    input_type=_DELETEJOBREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='StopJob',
    full_name='pps_1_7.API.StopJob',
    index=6,
    containing_service=None,
    input_type=_STOPJOBREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InspectDatum',
    full_name='pps_1_7.API.InspectDatum',
    index=7,
    containing_service=None,
    input_type=_INSPECTDATUMREQUEST,
    output_type=_DATUMINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListDatum',
    full_name='pps_1_7.API.ListDatum',
    index=8,
    containing_service=None,
    input_type=_LISTDATUMREQUEST,
    output_type=_LISTDATUMRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListDatumStream',
    full_name='pps_1_7.API.ListDatumStream',
    index=9,
    containing_service=None,
    input_type=_LISTDATUMREQUEST,
    output_type=_LISTDATUMSTREAMRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RestartDatum',
    full_name='pps_1_7.API.RestartDatum',
    index=10,
    containing_service=None,
    input_type=_RESTARTDATUMREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePipeline',
    full_name='pps_1_7.API.CreatePipeline',
    index=11,
    containing_service=None,
    input_type=_CREATEPIPELINEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InspectPipeline',
    full_name='pps_1_7.API.InspectPipeline',
    index=12,
    containing_service=None,
    input_type=_INSPECTPIPELINEREQUEST,
    output_type=_PIPELINEINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListPipeline',
    full_name='pps_1_7.API.ListPipeline',
    index=13,
    containing_service=None,
    input_type=_LISTPIPELINEREQUEST,
    output_type=_PIPELINEINFOS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeletePipeline',
    full_name='pps_1_7.API.DeletePipeline',
    index=14,
    containing_service=None,
    input_type=_DELETEPIPELINEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='StartPipeline',
    full_name='pps_1_7.API.StartPipeline',
    index=15,
    containing_service=None,
    input_type=_STARTPIPELINEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='StopPipeline',
    full_name='pps_1_7.API.StopPipeline',
    index=16,
    containing_service=None,
    input_type=_STOPPIPELINEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RerunPipeline',
    full_name='pps_1_7.API.RerunPipeline',
    index=17,
    containing_service=None,
    input_type=_RERUNPIPELINEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAll',
    full_name='pps_1_7.API.DeleteAll',
    index=18,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetLogs',
    full_name='pps_1_7.API.GetLogs',
    index=19,
    containing_service=None,
    input_type=_GETLOGSREQUEST,
    output_type=_LOGMESSAGE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GarbageCollect',
    full_name='pps_1_7.API.GarbageCollect',
    index=20,
    containing_service=None,
    input_type=_GARBAGECOLLECTREQUEST,
    output_type=_GARBAGECOLLECTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ActivateAuth',
    full_name='pps_1_7.API.ActivateAuth',
    index=21,
    containing_service=None,
    input_type=_ACTIVATEAUTHREQUEST,
    output_type=_ACTIVATEAUTHRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_API)

DESCRIPTOR.services_by_name['API'] = _API

# @@protoc_insertion_point(module_scope)
